Crate io_uring_owner

Crate io_uring_owner 

io-uring-owner

Owner types for the io_uring io_uring Owner types

Enums

Owner
Ownership denotes where the ownership stands in long living records and where it is important to know it’s status. All Accept, EpollCtl and Buffer records have varying dynamics how these are allocated and re-used and this requires a flexible type given re-allocation may be expensive in case of buffers whilst desierable just re-create record in Accept or EpollCtl case.
TakeError
Errors relating to taking (ownership)