pub enum Owner {
Created,
Registered,
Filling,
Taken,
Kernel,
Returned,
Reusable,
}Expand description
Ownership denotes where the ownership stands in long living records and where it is important to know it’s status. All Accept, EpollCtl and Buffer records have varying dynamics how these are allocated and re-used and this requires a flexible type given re-allocation may be expensive in case of buffers whilst desierable just re-create record in Accept or EpollCtl case.
Variants
Created
Record was created (default)
Registered
Registered (e.g. via ProvideBuffers)
Filling
User is filling the created buffer
Taken
Taken is owned intermediately internally before used
Kernel
Record is owned by the Kernel
Returned
Record is returned to the user(space)
Reusable
Record is marked for re-use (e.g. expensive allocation) Typical user: BufferRec
Implementations